from typing import Dict


def fuzzy_search(text: str) -> Dict:
    """
    Fuzzy query to search.
    This also returns the highlighted result.

    :param text: The text to be searched for.
    :return: Results of the query with highlighted content.
    """
    return {
        "query": {
            "match": {
                "content": {
                    "analyzer": "simple",
                    "query": "*" + text + "*",
                    "fuzziness": "AUTO",
                    "prefix_length": 1
                }
            }
        },
        "highlight": {
            "pre_tags": ["<em>"],
            "post_tags": ["</em>"],
            "fields": {
                "content": {
                    "highlight_query": {
                        "match": {
                            "content": {
                                "analyzer": "simple",
                                "query": "*" + text + "*",
                                "fuzziness": "AUTO",
                                "prefix_length": 1
                            }
                        }
                    }
                }
            }
        }
    }
